
//    Font Family

$primary-font	: 'Poppins', sans-serif;

/*--------------------------- Color variations ----------------------*/

$primary-color	: #ea6c5d;
$primary-color2	: #ff0000;
$title-color	: #222222;
$text-color		: #777777;

$white			: #fff;
$offwhite		: #f9f9ff;
$black			: #000;

// Placeholder Mixins
@mixin placeholder {
    &.placeholder {
        @content;
    }
    &:-moz-placeholder {
        @content;
    }
    &::-moz-placeholder {
        @content;
    }
    &::-webkit-input-placeholder {
        @content;
    }
}






